108
109
110
111
112
113
114
115
116
117
118
119
120
|
# File 'lib/cf/cli.rb', line 108
def
<<EOS
Cloud Foundry Command Line Interface, version [#{CF::VERSION}]
Use 'cf help [command]' for command details.
For docs and support visit http://support.cloudfoundry.com
USAGE EXAMPLES
$ cf target api.run.pivotal.io <-- sets the CF instance target where your app will be pushed
$ cf push <-- deploys app to current app space on current target
$ cf target -s staging <-- changes currently targeted app space to 'staging'
EOS
end
|